@@ -31,6 +31,6 @@ double NAK_Cpp(const NumericVector & X, double k) {
   NumericVector D_vec = abs(T2_vec - T3_vec);
 
   double D_max = max(D_vec);
-  return sqrt(n) *  D_max / Rf_choose(n, k);
+  return sqrt((double)n) *  D_max / Rf_choose(n, k);
 }
 
